@@ -29,37 +29,37 @@
 
 namespace kt
 {
-    class Core;
+class Core;
+
+/**
+ * @author Ivan Vasic
+ * @brief Torrent URL paste dialog
+ **/
+class PasteDialog: public QDialog, public Ui_PasteDlgBase
+{
+    Q_OBJECT
+public:
+    PasteDialog(Core* core, QWidget* parent = nullptr, Qt::WindowFlags fl = {});
+    ~PasteDialog() override;
 
     /**
-     * @author Ivan Vasic
-     * @brief Torrent URL paste dialog
-     **/
-    class PasteDialog: public QDialog, public Ui_PasteDlgBase
-    {
-        Q_OBJECT
-    public:
-        PasteDialog(Core* core, QWidget* parent = 0, Qt::WindowFlags fl = 0);
-        ~PasteDialog() override;
+    * Load the state of the dialog
+    */
+    void loadState(KSharedConfig::Ptr cfg);
 
-        /**
-        * Load the state of the dialog
-        */
-        void loadState(KSharedConfig::Ptr cfg);
+    /**
+    * Save the state of the dialog
+    */
+    void saveState(KSharedConfig::Ptr cfg);
 
-        /**
-        * Save the state of the dialog
-        */
-        void saveState(KSharedConfig::Ptr cfg);
+public Q_SLOTS:
+    void accept() override;
 
-    public slots:
-        void accept() override;
+private:
+    void loadGroups();
 
-    private:
-        void loadGroups();
-
-    private:
-        Core* m_core;
-    };
+private:
+    Core* m_core;
+};
 }
 #endif
