@@ -26,40 +26,40 @@
 
 namespace kt
 {
-    class IPFilterList;
+class IPFilterList;
 
-    /**
-    * @author Ivan Vasic <ivasic@gmail.com>
-    * @brief Integrated IPFilter GUI class.
-    * Used to show, add and remove banned peers from blacklist.
-    */
-    class IPFilterWidget: public QDialog, public Ui_IPFilterWidget
-    {
-        Q_OBJECT
-    public:
-        IPFilterWidget(QWidget* parent);
-        ~IPFilterWidget() override;
+/**
+* @author Ivan Vasic <ivasic@gmail.com>
+* @brief Integrated IPFilter GUI class.
+* Used to show, add and remove banned peers from blacklist.
+*/
+class IPFilterWidget: public QDialog, public Ui_IPFilterWidget
+{
+    Q_OBJECT
+public:
+    IPFilterWidget(QWidget* parent);
+    ~IPFilterWidget() override;
 
-        /// Register the filter list
-        static void registerFilterList();
+    /// Register the filter list
+    static void registerFilterList();
 
-        void saveFilter(const QString& fn);
-        static void loadFilter(const QString& fn);
+    void saveFilter(const QString& fn);
+    static void loadFilter(const QString& fn);
 
 
-    public slots:
-        void save();
-        void open() override;
-        void clear();
-        void remove();
-        void add();
-        void accept() override;
+public Q_SLOTS:
+    void save();
+    void open() override;
+    void clear();
+    void remove();
+    void add();
+    void accept() override;
 
-    private:
-        void setupConnections();
+private:
+    void setupConnections();
 
-        static IPFilterList* filter_list;
-    };
+    static IPFilterList* filter_list;
+};
 }
 
 #endif
