@@ -27,24 +27,24 @@
 namespace kt
 {
 
-    UngroupedGroup::UngroupedGroup(GroupManager* gman) : Group(i18n("Ungrouped Torrents"), MIXED_GROUP, QStringLiteral("/all/ungrouped")), gman(gman)
-    {
-        setIconByName(QStringLiteral("application-x-bittorrent"));
-    }
+UngroupedGroup::UngroupedGroup(GroupManager* gman) : Group(i18n("Ungrouped Torrents"), MIXED_GROUP, QStringLiteral("/all/ungrouped")), gman(gman)
+{
+    setIconByName(QStringLiteral("application-x-bittorrent"));
+}
 
 
-    UngroupedGroup::~UngroupedGroup()
-    {
-    }
+UngroupedGroup::~UngroupedGroup()
+{
+}
 
 
-    bool UngroupedGroup::isMember(TorrentInterface* tor)
-    {
-        for (GroupManager::Itr i = gman->begin(); i != gman->end(); i++)
-            if ((i->second->groupFlags() & Group::CUSTOM_GROUP) && i->second->isMember(tor))
-                return false;
+bool UngroupedGroup::isMember(TorrentInterface* tor)
+{
+    for (GroupManager::CItr i = gman->begin(); i != gman->end(); i++)
+        if ((i->second->groupFlags() & Group::CUSTOM_GROUP) && i->second->isMember(tor))
+            return false;
 
-        return true;
-    }
+    return true;
+}
 
 }
