@@ -31,59 +31,55 @@ using namespace bt;
 namespace kt
 {
 
-    StringCompletionModel::StringCompletionModel(const QString& file, QObject* parent): QStringListModel(parent), file(file)
-    {
+StringCompletionModel::StringCompletionModel(const QString& file, QObject* parent): QStringListModel(parent), file(file)
+{
+}
+
+
+StringCompletionModel::~StringCompletionModel()
+{
+}
+
+void StringCompletionModel::load()
+{
+    QFile fptr(file);
+    if (!fptr.open(QIODevice::ReadOnly)) {
+        Out(SYS_GEN | LOG_NOTICE) << "Failed to open " << file << " : " << fptr.errorString() << endl;
+        return;
     }
 
-
-    StringCompletionModel::~StringCompletionModel()
-    {
+    QSet<QString> strings;
+    while (!fptr.atEnd()) {
+        QString line = QString::fromUtf8(fptr.readLine().trimmed());
+        if (line.length() > 0)
+            strings.insert(line);
     }
 
-    void StringCompletionModel::load()
-    {
-        QFile fptr(file);
-        if (!fptr.open(QIODevice::ReadOnly))
-        {
-            Out(SYS_GEN | LOG_NOTICE) << "Failed to open " << file << " : " << fptr.errorString() << endl;
-            return;
-        }
+    setStringList(QList<QString>(strings.begin(), strings.end()));
+}
 
-        QSet<QString> strings;
-        while (!fptr.atEnd())
-        {
-            QString line = QString::fromUtf8(fptr.readLine().trimmed());
-            if (line.length() > 0)
-                strings.insert(line);
-        }
-
-        setStringList(strings.toList());
+void StringCompletionModel::save()
+{
+    QFile fptr(file);
+    if (!fptr.open(QIODevice::WriteOnly)) {
+        Out(SYS_GEN | LOG_NOTICE) << "Failed to open " << file << " : " << fptr.errorString() << endl;
+        return;
     }
 
-    void StringCompletionModel::save()
-    {
-        QFile fptr(file);
-        if (!fptr.open(QIODevice::WriteOnly))
-        {
-            Out(SYS_GEN | LOG_NOTICE) << "Failed to open " << file << " : " << fptr.errorString() << endl;
-            return;
-        }
+    QTextStream out(&fptr);
+    const QStringList sl = stringList();
+    for (const QString& s : sl)
+        out << s << Qt::endl;
+}
 
-        QTextStream out(&fptr);
-        const QStringList sl = stringList();
-        for (const QString& s : sl)
-            out << s << endl;
-    }
-
-    void StringCompletionModel::addString(const QString& s)
-    {
-        QStringList curr = stringList();
-        if (!curr.contains(s))
-        {
-            curr.append(s);
-            setStringList(curr);
-        }
+void StringCompletionModel::addString(const QString& s)
+{
+    QStringList curr = stringList();
+    if (!curr.contains(s)) {
+        curr.append(s);
+        setStringList(curr);
     }
+}
 
 }
 
